summaryrefslogtreecommitdiffstats
path: root/src/usr/local
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/local')
-rw-r--r--src/usr/local/www/services_ntpd_gps.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/usr/local/www/services_ntpd_gps.php b/src/usr/local/www/services_ntpd_gps.php
index 7b8751f..2781178 100644
--- a/src/usr/local/www/services_ntpd_gps.php
+++ b/src/usr/local/www/services_ntpd_gps.php
@@ -138,8 +138,8 @@ if ($_POST) {
unset($config['ntpd']['gps']['prefer']);
}
- if (!empty($_POST['gpsselect'])) {
- $config['ntpd']['gps']['noselect'] = $_POST['gpsselect'];
+ if (!empty($_POST['gpsnoselect'])) {
+ $config['ntpd']['gps']['noselect'] = $_POST['gpsnoselect'];
} elseif (isset($config['ntpd']['gps']['noselect'])) {
unset($config['ntpd']['gps']['noselect']);
}
@@ -321,7 +321,7 @@ $section->addInput(new Form_Checkbox(
));
$section->addInput(new Form_Checkbox(
- 'gpsselect',
+ 'gpsnoselect',
null,
'Do not use this clock, display for reference only (default: unchecked).',
$pconfig['noselect']
@@ -530,14 +530,14 @@ events.push(function() {
set_gps_default('<?=$pconfig['type']?>');
// Checkboxes gpsprefer and gpsselect are mutually exclusive
$('#gpsprefer').click(function() {
if ($(this).is(':checked')) {
- $('#gpsselect').prop('checked', false);
+ $('#gpsnoselect').prop('checked', false);
}
});
- $('#gpsselect').click(function() {
+ $('#gpsnoselect').click(function() {
if ($(this).is(':checked')) {
$('#gpsprefer').prop('checked', false);
}
@@ -530,14 +530,14 @@ events.push(function() {
set_gps_default('<?=$pconfig['type']?>');
- // Checkboxes gpsprefer and gpsselect are mutually exclusive
+ // Checkboxes gpsprefer and gpsnoselect are mutually exclusive
$('#gpsprefer').click(function() {
if ($(this).is(':checked')) {
OpenPOWER on IntegriCloud